==> rtp-1.3.0.tar.gz: rtp-1.3.0/tools/psins/psins.pl <==
#!/usr/bin/perl

# ====================================================================
# The Vovida Software License, Version 1.0 
# 
# Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. The names "VOCAL", "Vovida Open Communication Application Library",
#    and "Vovida Open Communication Application Library (VOCAL)" must
#    not be used to endorse or promote products derived from this
#    software without prior written permission. For written
#    permission, please contact vocal@vovida.org.
# 
# 4. Products derived from this software may not be called "VOCAL", nor
#    may "VOCAL" appear in their name, without prior written
#    permission of Vovida Networks, Inc.
# 
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
# NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
# NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
# IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
# OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
# 
# ====================================================================
# 
# This software consists of voluntary contributions made by Vovida
# Networks, Inc. and many individuals on behalf of Vovida Networks,
# Inc.  For more information on Vovida Networks, Inc., please see
# <http://www.vovida.org/>.

# $Id: psins.pl,v 1.3 2001/12/13 01:38:04 bko Exp $

use IO::Socket;
use Socket;
require "getopts.pl";

&Getopts("gp");

sub create_connection {
    my($addr, $port) = @_;

    my($remote);
    $remote = IO::Socket::INET->new( Proto     => "tcp",
                                     PeerAddr  => $addr,
                                     PeerPort  => $port,
                                   );
    return ($remote);
}

sub put_data_tcp {
    my($socket, $dirname, $filename, $data) = @_;
    my($len);

    $len = length($data);
    print $socket "PUT $dirname $filename\n";
    print $socket "Content-Length: $len\n";
    print $socket $data;
}


sub get_data_tcp {
    my($socket, $dirname, $filename) = @_;
    my($flag, $len, $buf, $data);
    my($gotheader);

    print $socket "GET $dirname $filename VPP/1.0\n\n";
    while(!$flag) {
	vec($rin, fileno($socket), 1) = 1;
	if(select($rin, undef, undef, undef)) {
	    @bits = split(//, unpack("b*", $rin));
	    if($bits[fileno($socket)]) {
#		print "reading...\n";
		$l = read($socket, $data, 1);
#		print "read $l bytes\n";
		$buf .= $data;
#		print "buf: $buf\n";
		if($gotheader) {
		    if($len == length($buf)) {
			$flag = 1;
		    }
		}
		if($buf =~ s/^200 OK\nContent-Length: ([0-9]*)\n//) {
		    $len = $1;
		    $gotheader = 1;
		}
	    }
	}
    }
    return $buf;
}


if($#ARGV != (4 - 1)) {
    &usage();
}

$port = 6005;
if($ARGV[0] =~ s/\:([0-9]+)$//) {
    $port = $1;
}
$sock = &create_connection($ARGV[0], $port);

if($opt_g) {
    $data = &get_data_tcp($sock, $ARGV[1], $ARGV[2]);
    open(DATA, ">$ARGV[3]") || die "can't open $ARGV[3]: $!";
    print DATA $data;
    close(DATA);
} elsif($opt_p) { 
    $data = "";
    open(DATA, $ARGV[3]) || die "can't open $ARGV[3]: $!";
    while(<DATA>) {
	$data .= $_;
    }
    close(DATA);
    &put_data_tcp($sock, $ARGV[1], $ARGV[2], $data);
} else {
    &usage();
}


sub usage {
    print "Usage: $0 [-gp] <hostname:port> <directory-name> <dest-filename> <file>\n";    
    print "    -g  GET file\n";
    print "    -p  PUT file\n";
    exit;
}

==> rtp-1.4.0.tar.gz: rtp-1.4.0/tools/psins/psins.pl <==
#!/usr/bin/perl

# ====================================================================
# The Vovida Software License, Version 1.0 
# 
# Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. The names "VOCAL", "Vovida Open Communication Application Library",
#    and "Vovida Open Communication Application Library (VOCAL)" must
#    not be used to endorse or promote products derived from this
#    software without prior written permission. For written
#    permission, please contact vocal@vovida.org.
# 
# 4. Products derived from this software may not be called "VOCAL", nor
#    may "VOCAL" appear in their name, without prior written
#    permission of Vovida Networks, Inc.
# 
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
# NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
# NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
# IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
# OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
# 
# ====================================================================
# 
# This software consists of voluntary contributions made by Vovida
# Networks, Inc. and many individuals on behalf of Vovida Networks,
# Inc.  For more information on Vovida Networks, Inc., please see
# <http://www.vovida.org/>.

# $Id: psins.pl,v 1.7 2002/03/30 01:34:18 bko Exp $

require "getopts.pl";
use lib "../../provisioning/web";
use psinslib ;

&Getopts("gpld");

$argument_count = $#ARGV + 1;

if($opt_g && $argument_count == 4) {
    $data = &get_data($ARGV[0], $ARGV[1], $ARGV[2]);
    if(!defined($data)) {
	die "cannot get data from provisioning server";
    }
    if($ARGV[3] eq '-') {
	# use stdin
	open(DATA, ">&1") || die "can't open stdout: $!";
    } else {
        open(DATA, ">$ARGV[3]") || die "can't open $ARGV[3]: $!";
    }
    print DATA $data;
    close(DATA);
} elsif($opt_p && $argument_count == 4) { 
    $data = "";
    if($ARGV[3] eq '-') {
	# use stdin
	open(DATA, "<&0") || die "can't open stdin: $!";
    } else {
        open(DATA, $ARGV[3]) || die "can't open $ARGV[3]: $!";
    }
    while(<DATA>) {
	$data .= $_;
    }
    close(DATA);
    $retval = &put_data($ARGV[0], $ARGV[1], $ARGV[2], $data);
    if($retval == -1) {
	die "cannot write to $ARGV[0]";
    }
} elsif($opt_l && $argument_count == 3) {
    $data = &list_data($ARGV[0], $ARGV[1]);
    if($ARGV[2] eq '-') {
	# use stdin
	open(DATA, ">&1") || die "can't open stdout: $!";
    } else {
        open(DATA, ">$ARGV[2]") || die "can't open $ARGV[2]: $!";
    }
    print DATA $data;
    close(DATA);
} elsif($opt_d && $argument_count == 2) {
    $data = &delete_user($ARGV[0], $ARGV[1]);
} else {
    &usage();
}


sub usage {
    print "Usage: $0 <options>\n";
    print "    Get:      -g <hostname:port> <directory-name> <dest-filename> <file>\n";
    print "    Put:      -p <hostname:port> <directory-name> <dest-filename> <file>\n";
    print "    List:     -l <hostname:port> <listname> <file>\n";
    print "    Delete:   -d <hostname:port> <user>\n";
    print "\n";
    exit;
}
